@@ -103,7 +103,8 @@ class GetSwitchbotDevices:
         """Return all WoSensorTH/Temp sensor devices with services data."""
         base_meters = await self._get_devices_by_model("T")
         plus_meters = await self._get_devices_by_model("i")
-        return {**base_meters, **plus_meters}
+        io_meters = await self._get_devices_by_model("w")
+        return {**base_meters, **plus_meters, **io_meters}
 
     async def get_contactsensors(self) -> dict[str, SwitchBotAdvertisement]:
         """Return all WoContact/Contact sensor devices with services data."""
